@@ -982,6 +982,16 @@ class Auth(object):
         })
         return Travis(**params)
 
+    def vast(self):
+        """Return an authenticated Vast object."""
+        from bitsapiclient.services.vast import Vast
+        params = self.secrets.resolve({
+            'server': self.settings['vast']['server'],
+            'username': self.settings['vast']['username'],
+            'password': self.settings['vast']['password'],
+        })
+        return Vast(**params)
+
     def vmware(self):
         """Connect to VMWare API."""
         from bitsapiclient.services.vmware import VMWare
